@@ -2477,7 +2477,7 @@ sub consolidate_orders {
 	    
       }
 
-      $ordnumber ||= $form->update_defaults($myconfig, $numberfld, $dbh);
+      $ordnumber = $form->update_defaults($myconfig, $numberfld, $dbh);
     
       $query = qq|INSERT INTO oe (ordnumber)
 		  VALUES ('$uid')|;
