@@ -212,8 +212,12 @@ function CheckAll(v) {
       $rows = 1;
     }
     
-    $form->{"description_$i"} = $form->quote($form->{"description_$i"});
-    $column_data{description} = qq|<td><textarea name="description_$i" rows=$rows cols=46 wrap=soft>$form->{"description_$i"}</textarea></td>|;
+    if ($i == $numrows) {
+      $column_data{description} = qq|<td><input name="description_$i" size=46></td>|;
+    } else {
+      $form->{"description_$i"} = $form->quote($form->{"description_$i"});
+      $column_data{description} = qq|<td><textarea name="description_$i" rows=$rows cols=46 wrap=soft>$form->{"description_$i"}</textarea></td>|;
+    }
 
     $skunumber = qq|
                 <br><b>$sku</b> $form->{"sku_$i"}| if ($form->{vc} eq 'vendor' && $form->{"sku_$i"});
@@ -247,7 +251,7 @@ function CheckAll(v) {
     }
 
     $column_data{runningnumber} = qq|<td><input name="runningnumber_$i" class="inputright" size="3" value="$i"></td>|;
-    $column_data{partnumber} = qq|<td nowrap><input name="partnumber_$i" size="15" value="|.$form->quote($form->{"partnumber_$i"}).qq|" accesskey="$i" title="[Alt-$i]">$skunumber$itemhref</td>|;
+    $column_data{partnumber} = qq|<td nowrap><input name="partnumber_$i" size="15" value="|.$form->quote($form->{"partnumber_$i"}).qq|" accesskey="$i" title="[$i]">$skunumber$itemhref</td>|;
     $column_data{qty} = qq|<td><input name="qty_$i" class="inputright" title="$form->{"onhand_$i"}" size="5" value="|.$form->format_amount(\%myconfig, $form->{"qty_$i"}).qq|"></td>|;
     $column_data{ship} = qq|<td><input name="ship_$i" class="inputright" size="5" value="|.$form->format_amount(\%myconfig, $form->{"ship_$i"}).qq|"></td>|;
     $column_data{unit} = qq|<td><input name="unit_$i" size="5" maxlength="5" value="|.$form->quote($form->{"unit_$i"}).qq|"></td>|;
@@ -1104,6 +1108,8 @@ sub create_form {
   $form->{rowcount}-- if $form->{rowcount};
   $form->{rowcount} = 0 if ! $form->{"$form->{vc}_id"};
 
+  $locale = new Locale "$myconfig{countrycode}", "oe";
+
   do "$form->{path}/$form->{script}";
 
   for ("$form->{vc}", "currency") { $form->{"select$_"} = "" }
@@ -1247,6 +1253,7 @@ sub send_email {
   
   for (keys %$form) { $oldform->{$_} = $form->{$_} }
   for (qw(media format)) { $oldform->{$_} = $form->{"old$_"} }
+  for (1 .. $oldform->{paidaccounts}) { $oldform->{"paid_$_"} = $form->parse_amount(\%myconfig, $form->{"paid_$_"}) }
 
   &print_form($oldform);
   
@@ -1635,7 +1642,7 @@ sub print_form {
 
   push @f, ("${inv}number", "${inv}date", "${due}date", "${inv}description");
   
-  push @f, qw(company address tel fax businessnumber username useremail dcn rvc);
+  push @f, qw(company address tel fax businessnumber username useremail);
 
   for (qw(notes intnotes)) { $form->{$_} =~ s/^\s+//g }
 
@@ -1673,7 +1680,7 @@ sub print_form {
 		    action	=> 'printed',
 		    id		=> $form->{id} );
 
-    if (defined %$oldform) {
+    if (%$oldform) {
       $oldform->{printed} = $form->{printed};
       $oldform->{audittrail} .= $form->audittrail("", \%myconfig, \%audittrail);
     }
@@ -1705,7 +1712,7 @@ sub print_form {
 		    action	=> 'emailed',
 		    id		=> $form->{id} );
    
-    if (defined %$oldform) {
+    if (%$oldform) {
       $oldform->{intnotes} = qq|$oldform->{intnotes}\n\n| if $oldform->{intnotes};
       $oldform->{intnotes} .= qq|[email]\n|
       .$locale->text('Date').qq|: $now\n|
@@ -1754,7 +1761,7 @@ sub print_form {
 		    action      => 'queued',
 		    id          => $form->{id} );
 
-    if (defined %$oldform) {
+    if (%$oldform) {
       $oldform->{queued} = $form->{queued};
       $oldform->{audittrail} .= $form->audittrail("", \%myconfig, \%audittrail);
     }
@@ -1770,7 +1777,7 @@ sub print_form {
 
 
   # if we got back here restore the previous form
-  if (defined %$oldform) {
+  if (%$oldform) {
 
     $oldform->{"${inv}number"} = $form->{"${inv}number"};
     $oldform->{dcn} = $form->{dcn};
